@@ -9,7 +9,8 @@ import time
 
 import ray
 from ray.experimental import internal_kv
-from ray.experimental.async_api import thread_safe_client
+# from ray.experimental.async_api import thread_safe_client
+from skydl.ray.experimental.async_api_patch0_8_1 import thread_safe_client
 
 logger = logging.getLogger(__name__)
 logger.setLevel("INFO")
